pub struct V4;Trait Implementations
Sourceimpl PieWrapVersion for V4
impl PieWrapVersion for V4
Sourcefn pie_wrap_key(
header: &'static str,
wrapping_key: &LocalKey,
key_data: Vec<u8>,
) -> Result<Vec<u8>, PasetoError>
fn pie_wrap_key( header: &'static str, wrapping_key: &LocalKey, key_data: Vec<u8>, ) -> Result<Vec<u8>, PasetoError>
Wrap the key
Sourcefn pie_unwrap_key<'key>(
header: &'static str,
wrapping_key: &LocalKey,
key_data: &'key mut [u8],
) -> Result<&'key [u8], PasetoError>
fn pie_unwrap_key<'key>( header: &'static str, wrapping_key: &LocalKey, key_data: &'key mut [u8], ) -> Result<&'key [u8], PasetoError>
Unwrap the key
Sourceimpl PkeSealingVersion for V4
impl PkeSealingVersion for V4
Sourceimpl PkeUnsealingVersion for V4
impl PkeUnsealingVersion for V4
Sourcefn unseal_key(
unsealing_key: &SecretKey,
key_data: Box<[u8]>,
) -> Result<LocalKey, PasetoError>
fn unseal_key( unsealing_key: &SecretKey, key_data: Box<[u8]>, ) -> Result<LocalKey, PasetoError>
Unseal the key using the secret key
Sourceimpl PwWrapVersion for V4
impl PwWrapVersion for V4
type Params = Params
Sourcefn pw_wrap_key(
header: &'static str,
pass: &[u8],
params: &Params,
key_data: Vec<u8>,
) -> Result<Vec<u8>, PasetoError>
fn pw_wrap_key( header: &'static str, pass: &[u8], params: &Params, key_data: Vec<u8>, ) -> Result<Vec<u8>, PasetoError>
Wrap the key using a password
Sourcefn get_params(key_data: &[u8]) -> Result<Self::Params, PasetoError>
fn get_params(key_data: &[u8]) -> Result<Self::Params, PasetoError>
Extract the params from the
Sourcefn pw_unwrap_key<'key>(
header: &'static str,
pass: &[u8],
key_data: &'key mut [u8],
) -> Result<&'key [u8], PasetoError>
fn pw_unwrap_key<'key>( header: &'static str, pass: &[u8], key_data: &'key mut [u8], ) -> Result<&'key [u8], PasetoError>
Unwrap the key using a password
Sourceimpl SealingVersion<Local> for V4
Available on crate feature encrypting only.
impl SealingVersion<Local> for V4
Available on crate feature
encrypting only.Sourcefn unsealing_key(key: &LocalKey) -> LocalKey
fn unsealing_key(key: &LocalKey) -> LocalKey
Generate the key that can unseal the tokens this key will seal.
Sourcefn dangerous_seal_with_nonce(
key: &LocalKey,
encoding: &'static str,
payload: Vec<u8>,
footer: &[u8],
aad: &[u8],
) -> Result<Vec<u8>, PasetoError>
fn dangerous_seal_with_nonce( key: &LocalKey, encoding: &'static str, payload: Vec<u8>, footer: &[u8], aad: &[u8], ) -> Result<Vec<u8>, PasetoError>
Do not call this method directly. Use
UnsealedToken::seal instead.Sourceimpl SealingVersion<Public> for V4
Available on crate feature signing only.
impl SealingVersion<Public> for V4
Available on crate feature
signing only.Sourcefn unsealing_key(key: &SecretKey) -> PublicKey
fn unsealing_key(key: &SecretKey) -> PublicKey
Generate the key that can unseal the tokens this key will seal.
Sourcefn dangerous_seal_with_nonce(
key: &SecretKey,
encoding: &'static str,
payload: Vec<u8>,
footer: &[u8],
aad: &[u8],
) -> Result<Vec<u8>, PasetoError>
fn dangerous_seal_with_nonce( key: &SecretKey, encoding: &'static str, payload: Vec<u8>, footer: &[u8], aad: &[u8], ) -> Result<Vec<u8>, PasetoError>
Do not call this method directly. Use
UnsealedToken::seal instead.Sourceimpl UnsealingVersion<Local> for V4
Available on crate feature decrypting only.
impl UnsealingVersion<Local> for V4
Available on crate feature
decrypting only.Sourceimpl UnsealingVersion<Public> for V4
Available on crate feature verifying only.
impl UnsealingVersion<Public> for V4
Available on crate feature
verifying only.Auto Trait Implementations
impl Freeze for V4
impl RefUnwindSafe for V4
impl Send for V4
impl Sync for V4
impl Unpin for V4
impl UnwindSafe for V4